package org.openintents.samples.BasicOpenARDemo;

import java.util.ArrayList;
import java.util.Collection;

import org.openintents.intents.WikitudeARIntent;
import org.openintents.intents.WikitudePOI;

import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.res.Resources;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

/**
 * This sample application demonstrates the basic usage of the Wikitude Open AR
 * (augmented reality) API.<br/>
 * 
 * The basic usage is to create a list of POIs (points of interest) that is sent
 * to the AR application through intent extras.<br/>
 * 
 * Optional extras can be set to customize the icons or the title bar.
 * 
 * @author Peli
 * 
 */
public class BasicOpenARDemoActivity extends Activity {

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		// We hook up 3 different buttons.
		Button b = (Button) findViewById(R.id.button1);
		b.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				startARViewBasic();
			}
		});

		b = (Button) findViewById(R.id.button2);
		b.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				startARViewWithIcons();
			}
		});

		b = (Button) findViewById(R.id.button3);
		b.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				startARViewWithCustomTitle();
			}
		});
	}

	/**
	 * starts the basic AR view
	 */
	private void startARViewBasic() {

		// Create the basic intent
		WikitudeARIntent intent = prepareIntent();

		// Optionally add a title
		intent.addTitleText("My first AR application");

		// And launch the intent
		try {
			startActivity(intent);
		} catch (ActivityNotFoundException e) {
			Toast.makeText(this, R.string.toast_ar_not_found,
					Toast.LENGTH_SHORT).show();
		}
	}

	/**
	 * does the same as the basic AR view above, but adds custom icons to the
	 * POIs
	 */
	void startARViewWithIcons() {

		// Create the basic intent
		WikitudeARIntent intent = prepareIntent();

		// Optionally add a title
		intent.addTitleText("AR app with custom icons");

		// Optionally: Add icons
		addIcons(intent);

		// And launch the intent
		try {
			startActivity(intent);
		} catch (ActivityNotFoundException e) {
			Toast.makeText(this, R.string.toast_ar_not_found,
					Toast.LENGTH_SHORT).show();
		}
	}

	/**
	 * does the same as the basic AR view above, but adds custom icons to the
	 * POIs and a graphical title image
	 */
	void startARViewWithCustomTitle() {
		// Create the basic intent
		WikitudeARIntent intent = prepareIntent();

		// Optionally: Add icons
		addIcons(intent);

		// Optionally: Put a custom graphical title:
		intent.addTitleImageResource(this.getResources().getResourceName(
				R.drawable.custom_title_bar));

		if (this.falseNoWarning()) {
			// THE FOLLOWING CODE IS INACTIVE, AND ONLY INCLUDED FOR
			// DEMONSTRATION PURPOSES:

			// Alternatively, the title could be retrieved from a content
			// provider:
			intent.addTitleImageUri("content://media/external/images/media/1");
		}

		// And launch the intent
		try {
			startActivity(intent);
		} catch (ActivityNotFoundException e) {
			Toast.makeText(this, R.string.toast_ar_not_found,
					Toast.LENGTH_SHORT).show();
		}
	}

	/**
	 * prepares a Wikitude AR Intent (e.g. adds the POIs to the view)
	 * 
	 * @return the prepared intent
	 */
	private WikitudeARIntent prepareIntent() {
		// create the intent
		WikitudeARIntent intent = new WikitudeARIntent(this.getApplication(),
				null, null);
		// add the POIs
		this.addPois(intent);
		return intent;
	}

	/**
	 * adds hard-coded POIs to the intent
	 * 
	 * @param intent
	 *            the intent
	 */
	private void addPois(WikitudeARIntent intent) {
		WikitudePOI poi1 = new WikitudePOI(35.683333, 139.766667, 36, "Tokyo",
				"Tokyo is the capital of Japan.");
		WikitudePOI poi2 = new WikitudePOI(
				41.9,
				12.5,
				14,
				"Rome",
				"Rome is the capital of Italy and the country's largest and most populous city, with over 2.7 million residents.");
		WikitudePOI poi3 = new WikitudePOI(
				40.716667,
				-74,
				1,
				"New York",
				"New York is the most populous city in the United States, and the center of the New York metropolitan area.");
		WikitudePOI poi4 = new WikitudePOI(
				48.208333,
				16.373056,
				220,
				"Vienna",
				"Vienna is the capital of the Republic of Austria.");
		Collection<WikitudePOI> pois = new ArrayList<WikitudePOI>();
		pois.add(poi1);
		pois.add(poi2);
		pois.add(poi3);
		pois.add(poi4);
		intent.addPOIs(pois);
	}

	/**
	 * helper-method to add icons to the intent.
	 * 
	 * @param intent
	 *            the intent
	 */
	private void addIcons(WikitudeARIntent intent) {
		// Optionally: Set icons for the POIs.
		// You can either set icons from resources or through a content
		// provider.
		// In this example, icons from resources are used:

		ArrayList<WikitudePOI> pois = intent.getPOIs();

		Resources res = getResources();
		pois.get(0).setIconresource(res.getResourceName(R.drawable.flag_japan));
		pois.get(1).setIconresource(res.getResourceName(R.drawable.flag_italy));
		pois.get(2).setIconresource(res.getResourceName(R.drawable.flag_usa));
		pois.get(3).setIconresource(
				res.getResourceName(R.drawable.flag_austria));

		if (this.falseNoWarning()) {
			// THE FOLLOWING CODE IS INACTIVE, AND ONLY INCLUDED
			// FOR DEMONSTRATION PURPOSES:

			// Alternatively, one could set URIs:
			// Use Android's content provider or create your own
			// to host your custom images.
			pois.get(0).setIconuri("content://media/external/images/media/1");
		}
	}

	/**
	 * returns always false (avoids getting a compiler-warning on "dead code"
	 * above)
	 * 
	 * @return false
	 */
	private boolean falseNoWarning() {
		return false;
	}

}